// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef KCOREADDONS_VERSION_H
#define KCOREADDONS_VERSION_H

#define KCOREADDONS_VERSION_STRING "5.110.0"
#define KCOREADDONS_VERSION_MAJOR 5
#define KCOREADDONS_VERSION_MINOR 110
#define KCOREADDONS_VERSION_PATCH 0
#define KCOREADDONS_VERSION ((5<<16)|(110<<8)|(0))

#endif
